@@ -1,11 +1,13 @@
 # This is the bcfg2 support for blastwave packages (pkg-get)
-"""This provides bcfg2 support for blastwave"""
+"""This provides Bcfg2 support for Blastwave."""
 __revision__ = '$Revision$'
 
-import Bcfg2.Client.Tools.SYSV, tempfile
+import tempfile
+import Bcfg2.Client.Tools.SYSV
+
 
 class Blast(Bcfg2.Client.Tools.SYSV.SYSV):
-    """Support for Blastwave packages"""
+    """Support for Blastwave packages."""
     pkgtype = 'blast'
     pkgtool = ("/opt/csw/bin/pkg-get install %s", ("%s", ["bname"]))
     name = 'Blast'
@@ -27,7 +29,6 @@ class Blast(Bcfg2.Client.Tools.SYSV.SYSV):
     # Install comes from Bcfg2.Client.Tools.PkgTool
     # Extra comes from Bcfg2.Client.Tools.Tool
     # Remove comes from Bcfg2.Client.Tools.SYSV
-
     def FindExtraPackages(self):
         """Pass through to null FindExtra call."""
         return []
