@@ -22,10 +22,12 @@ import socket
 try:
     import ssl
     SSL_LIB = 'py26_ssl'
+    SSL_ERROR = ssl.SSLError
 except ImportError:
     from M2Crypto import SSL
     import M2Crypto.SSL.Checker
     SSL_LIB = 'm2crypto'
+    SSL_ERROR = SSL.SSLError
 
 
 import sys
@@ -49,18 +51,20 @@ class ProxyError(Exception):
     the various xmlrpclib errors that might arise (mainly
     ProtocolError and Fault) """
     def __init__(self, err):
+        msg = None
         if isinstance(err, xmlrpclib.ProtocolError):
             # cut out the password in the URL
             url = re.sub(r'([^:]+):(.*?)@([^@]+:\d+/)', r'\1:******@\3',
                          err.url)
-            self.message = "XML-RPC Protocol Error for %s: %s (%s)" % \
-                           (url, err.errmsg, err.errcode)
+            msg = "XML-RPC Protocol Error for %s: %s (%s)" % (url,
+                                                              err.errmsg,
+                                                              err.errcode)
         elif isinstance(err, xmlrpclib.Fault):
-            self.message = "XML-RPC Fault: %s (%s)" % (err.faultString,
-                                                       err.faultCode)
+            msg = "XML-RPC Fault: %s (%s)" % (err.faultString,
+                                              err.faultCode)
         else:
-            self.message = str(err)
-        self.args = (self.message, )
+            msg = str(err)
+        Exception(self, msg)
 
 class CertificateError(Exception):
     def __init__(self, commonName):
@@ -298,19 +302,14 @@ class XMLRPCTransport(xmlrpclib.Transport):
     def request(self, host, handler, request_body, verbose=0):
         """Send request to server and return response."""
         h = self.make_connection(host)
-        self.send_request(h, handler, request_body)
-        self.send_host(h, host)
-        self.send_user_agent(h)
-        self.send_content(h, request_body)
-
-        if SSL_LIB == 'py26_ssl':
-            catch = ssl.SSLError
-        elif SSL_LIB == 'm2crypto':
-            catch = SSL.SSLError
 
         try:
+            self.send_request(h, handler, request_body)
+            self.send_host(h, host)
+            self.send_user_agent(h)
+            self.send_content(h, request_body)
             errcode, errmsg, headers = h.getreply()
-        except catch:
+        except (socket.error, SSL_ERROR):
             err = sys.exc_info()[1]
             raise ProxyError(xmlrpclib.ProtocolError(host + handler,
                                                      408,
