@@ -16,9 +16,6 @@ class Tidy(Bcfg2.Server.Admin.Mode):
                  "-I",
                  "interactive"))
 
-    def __init__(self, cfile):
-        Bcfg2.Server.Admin.Mode.__init__(self, cfile)
-
     def __call__(self, args):
         Bcfg2.Server.Admin.Mode.__call__(self, args)
         badfiles = self.buildTidyList()
@@ -49,7 +46,7 @@ class Tidy(Bcfg2.Server.Admin.Mode):
         bad = []
 
         # clean up unresolvable hosts in SSHbase
-        for name in os.listdir("%s/SSHbase" % (self.get_repo_path())):
+        for name in os.listdir("%s/SSHbase" % self.setup['repo']):
             if hostmatcher.match(name):
                 hostname = hostmatcher.match(name).group(1)
                 if hostname in good + bad:
@@ -59,14 +56,14 @@ class Tidy(Bcfg2.Server.Admin.Mode):
                     good.append(hostname)
                 except:
                     bad.append(hostname)
-        for name in os.listdir("%s/SSHbase" % (self.get_repo_path())):
+        for name in os.listdir("%s/SSHbase" % self.setup['repo']):
             if not hostmatcher.match(name):
-                to_remove.append("%s/SSHbase/%s" % (self.get_repo_path(),
+                to_remove.append("%s/SSHbase/%s" % (self.setup['repo'],
                                                     name))
             else:
                 if hostmatcher.match(name).group(1) in bad:
                     to_remove.append("%s/SSHbase/%s" %
-                                    (self.get_repo_path(), name))
+                                    (self.setup['repo'], name))
         # clean up file~
         # clean up files without parsable names in Cfg
         return to_remove
