@@ -1,9 +1,10 @@
-from ConfigParser import ConfigParser, NoSectionError, NoOptionError
 import os.path
+# Compatibility import
+from Bcfg2.Bcfg2Py3k import ConfigParser
 
 PROJECT_ROOT = os.path.abspath(os.path.dirname(__file__))
 
-c = ConfigParser()
+c = ConfigParser.ConfigParser()
 #This needs to be configurable one day somehow
 c.read(['./bcfg2.conf'])
 
@@ -27,7 +28,7 @@ else:
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 ADMINS = (
-    # ('Your Name', 'your_email@domain.com'),
+     ('Root', 'root'),
 )
 MANAGERS = ADMINS
 
@@ -44,8 +45,11 @@ DATABASE_HOST = options['database_host']
 # Set to empty string for default. Not used with sqlite3.
 DATABASE_PORT = int(options['database_port'])
 # Local time zone for this installation. All choices can be found here:
-# http://www.postgresql.org/docs/current/static/datetime-keywords.html#DATETIME-TIMEZONE-SET-TABLE
-TIME_ZONE = 'America/Chicago'
+# http://docs.djangoproject.com/en/dev/ref/settings/#time-zone
+try:
+    TIME_ZONE = c.get('statistics', 'time_zone')
+except:
+    TIME_ZONE = None
 
 # enter the defauly MX record machines will get in Hostbase
 # this setting may move elsewhere eventually
