@@ -992,6 +992,12 @@ class EntrySet:
             self.entry_init(event)
         else:
             if event.filename not in self.entries:
+                logger.warning("Got %s event for unknown file %s" %
+                               (action, event.filename))
+                if action == 'changed':
+                    # received a bogus changed event; warn, but treat
+                    # it like a created event
+                    self.entry_init(event)
                 return
             if action == 'changed':
                 self.entries[event.filename].handle_event(event)
@@ -1157,8 +1163,11 @@ class GroupSpool(Plugin, Generator):
                 # a directory was deleted
                 del self.entries[fbase]
                 del self.Entries['Path'][fbase]
-            else:
+            elif ident in self.entries:
                 self.entries[ident].handle_event(event)
+            elif ident not in self.entries:
+                self.logger.warning("Got deleted event for unknown file %s" %
+                                    ident)
 
     def AddDirectoryMonitor(self, relative):
         """Add new directory to FAM structures."""
