@@ -7,7 +7,7 @@ class PackagesConfig(Bcfg2.Server.Plugin.SimpleConfig):
         """ Build local data structures """
         Bcfg2.Server.Plugin.SimpleConfig.Index(self)
 
-        if self.plugin.sources.loaded:
+        if hasattr(self.plugin, "sources") and self.plugin.sources.loaded:
             # only reload Packages plugin if sources have been loaded.
             # otherwise, this is getting called on server startup, and
             # we have to wait until all sources have been indexed
