@@ -124,6 +124,7 @@ class YumCollection(Collection):
             mainopts = dict(cachedir=self.cachefile,
                             keepcache="0",
                             sslverify="0",
+                            debuglevel="0",
                             reposdir="/dev/null")
             try:
                 for opt in self.config.options("yum"):
@@ -394,6 +395,11 @@ class YumCollection(Collection):
         if rv:
             self.logger.error("Packages: error running bcfg2-yum-helper "
                               "(returned %d): %s" % (rv, stderr))
+        elif self.debug_flag:
+            self.logger.debug("Packages: debug info from bcfg2-yum-helper: %s" %
+                              stderr)
+            self.logger.debug("Packages: output from bcfg2-yum-helper: %s" %
+                              stderr)
         try:
             return json.loads(stdout)
         except ValueError:
