@@ -3,7 +3,11 @@ __revision__ = '$Revision$'
 
 import binascii
 import logging
+import sys
 import Bcfg2.Server.Plugin
+# py3k compatibility
+if sys.hexversion >= 0x03000000:
+    unicode = str
 
 logger = logging.getLogger('Bcfg2.Plugins.TGenshi')
 
@@ -63,11 +67,14 @@ class TemplateFile:
             try:
                 self.template = loader.load(self.name, cls=self.template_cls,
                                             encoding=self.encoding)
-            except LookupError, lerror:
+            except LookupError:
+                lerror = sys.exc_info()[1]
                 logger.error('Genshi lookup error: %s' % lerror)
-        except TemplateError, terror:
+        except TemplateError:
+            terror = sys.exc_info()[1]
             logger.error('Genshi template error: %s' % terror)
-        except genshi.input.ParseError, perror:
+        except genshi.input.ParseError:
+            perror = sys.exc_info()[1]
             logger.error('Genshi parse error: %s' % perror)
 
     def bind_entry(self, entry, metadata):
@@ -92,7 +99,7 @@ class TemplateFile:
                     entry.text = textdata
                 else:
                     if entry.get('encoding') == 'base64':
-			# take care of case where file needs base64 encoding
+                        # take care of case where file needs base64 encoding
                         entry.text = binascii.b2a_base64(textdata)
                     else:
                         entry.text = unicode(textdata, self.encoding)
@@ -105,10 +112,14 @@ class TemplateFile:
                     entry.text = xmldata
                 else:
                     entry.text = unicode(xmldata, self.encoding)
-        except TemplateError, terror:
+            if entry.text == '':
+                entry.set('empty', 'true')
+        except TemplateError:
+            terror = sys.exc_info()[1]
             logger.error('Genshi template error: %s' % terror)
             raise Bcfg2.Server.Plugin.PluginExecutionError
-        except AttributeError, err:
+        except AttributeError:
+            err = sys.exc_info()[1]
             logger.error('Genshi template loading error: %s' % err)
             raise Bcfg2.Server.Plugin.PluginExecutionError
 
