@@ -2,7 +2,8 @@ __all__ = ['models', 'db_from_config', 'setup_session']
 
 import sqlalchemy
 import sqlalchemy.orm
-import ConfigParser
+# Compatibility import
+from Bcfg2.Bcfg2Py3k import ConfigParser
 
 
 def db_from_config(cfile):
@@ -19,7 +20,7 @@ def db_from_config(cfile):
         db = cp.get('snapshots', 'database')
         return '%s://%s:%s@%s/%s' % (driver, user, password, host, db)
     else:
-        raise Exception, "unsupported db driver %s" % driver
+        raise Exception("unsupported db driver %s" % driver)
 
 
 def setup_session(cfile, debug=False):
