@@ -1,4 +1,4 @@
-'''base modules definition'''
-__revision__ = '$Revision: 5225 $'
+"""Base modules definition."""
+__revision__ = '$Revision$'
 
 __all__ = ['Server', 'Client', 'Component', 'Logger', 'Options', 'Proxy', 'Statistics']
